==> nextcloud-app-spreed-1%3a6.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/bg.js <==
OC.L10N.register(
    "spreed",
    {
    "Chat" : "Съобщения",
    "Copy" : "Копиране",
    "Copied!" : "Копирано!",
    "Not supported!" : "Не се поддържа!",
    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C",
    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C",
    "Share" : "Споделяне",
    "Password required" : "Паролата е задължителна",
    "Password" : "Парола",
    "Cancel" : "Отказ",
    "Submit" : "Изпращане",
    "Share link" : "Сподели връзка",
    "Name" : "Име",
    "Rename" : "Преименуване",
    "Copy link" : "Копирай връзката",
    "Link copied!" : "Връзката е копирана!",
    "You" : "Ти",
    "Send" : "Изпрати",
    "Guest" : "Гост",
    "Please use a different browser like Firefox or Chrome" : "Моля, използвайте друг браузър като Firefox или Chrome",
    "Disable video" : "Изключване на видеото",
    "Share screen" : "Споделяне на екран",
    "Access to microphone & camera is only possible with HTTPS" : "Достъпът до микрофона и камерата е възможен само при HTTPS",
    "Access to microphone & camera was denied" : "Достъпът до микрофона и камерата е отказан",
    "Error while accessing microphone & camera" : "Грешка при достъп до микрофон и камера",
    "User" : "Потребител",
    "Everyone" : "Всички",
    "Users" : "Потребители",
    "TURN server URL" : "URL на TURN сървъра",
    "Validate SSL certificate" : "Проверка на SSL сертификата",
    "STUN server URL" : "URL на STUN сървъра",
    "TURN server protocols" : "Протоколи на TURN сървър",
    "UDP and TCP" : "UDP и TCP",
    "UDP only" : "само UDP",
    "TCP only" : "само TCP",
    "Commands" : "Команди",
    "Beta" : "Бета",
    "Saved" : "Запазено",
    "STUN servers" : "STUN сървъри",
    "TURN server" : "TURN сървър",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN сървърът се използва като прокси сървър за трафика, идващ от участници стоящи зад защитна стена.",
    "Delete server" : "Изтриване на сървъра",
    "Add new server" : "Добавете нов сървър"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3a7.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/bg.js <==
OC.L10N.register(
    "spreed",
    {
    "Guest" : "Гост",
    "User" : "Потребител",
    "Everyone" : "Всички",
    "Users" : "Потребители",
    "TURN server URL" : "URL на TURN сървъра",
    "Validate SSL certificate" : "Проверка на SSL сертификата",
    "STUN server URL" : "URL на STUN сървъра",
    "TURN server protocols" : "Протоколи на TURN сървър",
    "UDP and TCP" : "UDP и TCP",
    "UDP only" : "само UDP",
    "TCP only" : "само TCP",
    "Copy link" : "Копирай връзката",
    "Share link" : "Сподели връзка",
    "Commands" : "Команди",
    "Beta" : "Бета",
    "Name" : "Име",
    "Saved" : "Запазено",
    "STUN servers" : "STUN сървъри",
    "Password" : "Парола",
    "TURN server" : "TURN сървър",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN сървърът се използва като прокси сървър за трафика, идващ от участници стоящи зад защитна стена.",
    "Delete server" : "Изтриване на сървъра",
    "Add new server" : "Добавете нов сървър",
    "Chat" : "Съобщения",
    "Copy" : "Копиране",
    "Copied!" : "Копирано!",
    "Not supported!" : "Не се поддържа!",
    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C",
    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C",
    "Share" : "Споделяне",
    "Password required" : "Паролата е задължителна",
    "Cancel" : "Отказ",
    "Submit" : "Изпращане",
    "Rename" : "Преименуване",
    "Link copied!" : "Връзката е копирана!",
    "You" : "Ти",
    "Send" : "Изпрати",
    "Please use a different browser like Firefox or Chrome" : "Моля, използвайте друг браузър като Firefox или Chrome",
    "Disable video" : "Изключване на видеото",
    "Share screen" : "Споделяне на екран",
    "Access to microphone & camera is only possible with HTTPS" : "Достъпът до микрофона и камерата е възможен само при HTTPS",
    "Access to microphone & camera was denied" : "Достъпът до микрофона и камерата е отказан",
    "Error while accessing microphone & camera" : "Грешка при достъп до микрофон и камера"
},
"nplurals=2; plural=(n != 1);");
